// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// CalIndex -- XMM Science Analysis System
//
// Giuseppe Vacanti, XMM-SOC, European Space Agency
//   

#ifndef CalIndex_H
#define CalIndex_H

#include <string>
#include <set>
#include <Tracer.h>
#include "CcfConstituent.h"
#include <STime.h>

class CalIndex : public list<CcfConstituent *> {
 public:

  CalIndex(const string name, const bool master = false, const string category = "XMMCCF");
  virtual ~CalIndex() {}
  virtual void addConstituent(CcfConstituent * c);
  virtual bool removeConstituent(CcfConstituent * c);
  virtual bool removeConstituent(const string type, const string scope);
  virtual void addConstituentsFromSet(const string set);
  virtual void save(const bool fullpath = false, const STime& analysisdate = STime("now"),
		    const STime& observationdate = STime("now")) const;
  virtual string name() const;
  virtual string category() const;
  virtual void print(ostream & os) const;
  
 private:
  
  string _name, _category;
  bool _master, _exists;
  set<string, less<string> > _tally;

};

inline string CalIndex::name() const { PROC RETURN _name; }
inline string CalIndex::category() const { PROC RETURN _category; }

inline ostream & operator<<(ostream & os, const CalIndex & d)
{
  d.print(os);
  return os;
}


#endif


