// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// CcfConstituent -- XMM Science Analysis System
//
// A class to manipulate a constituent of the XMM CCF.
//
// Giuseppe Vacanti, XMM-SOC, European Space Agency
//
// $Id: CcfConstituent.h,v 1.8 2001/12/21 14:26:01 gvacanti Exp $

#ifndef CcfConstituent_H
#define CcfConstituent_H

// C++
#include <string>

// SAS
#include <DirEntry.h>
#include <STime.h>

class CcfConstituent : public virtual DirEntry {

 public:

  virtual ~CcfConstituent() {}

  virtual bool isValid() const = 0;
  virtual string telescope() const = 0;
  virtual string type() const = 0;
  virtual string scope() const = 0;
  virtual int issue() const = 0;
  virtual string extSequence() const = 0;
  virtual string extSequenceIdentifier() const = 0;
  virtual STime valdate() const = 0;
  virtual STime endvaldate() const = 0;
  virtual bool hasEndvaldate() const = 0;
  virtual STime date() const = 0;
  virtual STime subdate() const = 0;
  virtual string creator() const = 0;
  virtual string category() const = 0;

  virtual void print(ostream & os) const = 0;

  virtual bool operator==(const CcfConstituent & rhs) const = 0;
  virtual bool operator!=(const CcfConstituent & rhs) const = 0;
  virtual bool operator<(const CcfConstituent & rhs) const = 0;
  virtual bool operator>(const CcfConstituent & rhs) const = 0;

  static bool compare(const CcfConstituent * lhs, const CcfConstituent * rhs);
  static bool equal(const CcfConstituent * lhs, const CcfConstituent * rhs);
  
};

inline ostream & operator<<(ostream & os, const CcfConstituent & d)
{
  d.print(os);
  return os;
}

// This should be used to sort a list<CcfConstituent *> l:
//     l.sort(CcfConstituent::compare);
inline bool CcfConstituent::compare(const CcfConstituent * lhs, const CcfConstituent * rhs) {
 return *lhs < *rhs;  
}

// This should be used to make the sorted list unique:
//  iterator p = unique(l.begin(), l.end());
//  l.erase(p,l.end())
inline bool CcfConstituent::equal(const CcfConstituent * lhs, const CcfConstituent * rhs) {
  return *lhs == *rhs;
}

#endif
