// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#include <Tracer.h>
#include <Dal.h>

#include "CcfConstituentFactory.h"
#include "CcfConstituent.h"
#include "RealCcfConstituent.h"
#include "VirtualCcfConstituent.h"
#include "DirEntry.h"

CcfConstituentFactory::CcfConstituentFactory() { PROC ENDPROC }

static CcfConstituentFactory * initCcfConstituentFactory()
{
  PROC
  static bool init = true;
  if(init){
    init = false;
    ALTRETURNV(new CcfConstituentFactory);
  } else {
    ALTRETURNV(ccfConstituentFactory);
  }
  ENDPROC
}

CcfConstituentFactory * ccfConstituentFactory = initCcfConstituentFactory();

CcfConstituent * CcfConstituentFactory::ccfConstituent(const string name) const
{
  PROC
  RETURN(new RealCcfConstituent(name));
}

CcfConstituent * CcfConstituentFactory::ccfConstituent(const Table * table, unsigned long row ) const
{
  PROC
  RETURN(new VirtualCcfConstituent(table, row));
}

