// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// CommonCcfConstituent -- XMM Science Analysis System
//
// Common code for the implementation of CcfConstituent
//
// Giuseppe Vacanti, XMM-SOC, European Space Agency
//   

#ifndef CommonCcfConstituent_H
#define CommonCcfConstituent_H

// C++
#include <string>

// SAS
#include "STime.h"

#include "CcfConstituent.h"
#include "DirEntryImplementation.h"

class CommonCcfConstituent : public virtual CcfConstituent, public DirEntryImplementation
{

 public:

  CommonCcfConstituent(const string name);

  virtual ~CommonCcfConstituent() {}

  virtual bool isValid() const;
  virtual string telescope() const;
  virtual string type() const;
  virtual string scope() const;
  virtual int issue() const;
  virtual string extSequence() const;
  virtual string extSequenceIdentifier() const;
  virtual STime valdate() const;
  virtual STime endvaldate() const;
  virtual bool hasEndvaldate() const;
  virtual STime date() const;
  virtual STime subdate() const;
  virtual string creator() const;
  virtual string category() const;

  virtual void print(ostream & os) const;

  virtual bool operator==(const CcfConstituent & rhs) const;
  virtual bool operator!=(const CcfConstituent & rhs) const;
  virtual bool operator<(const CcfConstituent & rhs) const;
  virtual bool operator>(const CcfConstituent & rhs) const;

 protected:

  CommonCcfConstituent();

 private:

  virtual void init();

  string _telescope, _scope, _type, _extSequence,
    _extSequenceIdentifier, _creator, _category;
  int _issue;
  STime _valdate, _evaldate, _date, _subdate, _initdate;
  bool _isValid;
  bool _init_done;
  bool _has_endvaldate;
  
};

#endif
