// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#include <Tracer.h>
#include <Dal.h>
#include <errstr.h>
#include <SasDalUtils.h>

#include "CalIndexColumns.h"
#include "VirtualCcfConstituent.h"

VirtualCcfConstituent::VirtualCcfConstituent(const Table * table, const unsigned long row) : _has_endvaldate(false)
{
  PROC
  ColumnData * ptr;

  _category = table->attribute("CATEGORY")->asString();

  ptr = table->column(FSIZE)->data();
  int32 * s = ptr->int32Data();
  _size = s[row];
  delete ptr;

  ptr = table->column(ISSUE)->data();
  int16 * i = ptr->int16Data();
  _issue = i[row];
  delete ptr;

  using namespace SasDalUtils;
  ptr = table->column(TELESCOPE)->data();
  _telescope = getStringColumnRow(ptr, row);
  delete ptr;
  
  ptr = table->column(SCOPE)->data();
  _scope = getStringColumnRow(ptr, row);
  delete ptr;
  
  ptr = table->column(TYPE_ID)->data();
  _type = getStringColumnRow(ptr, row);
  delete ptr;

  ptr = table->column(VALDATE)->data();
  _valdate = getStringColumnRow(ptr, row);
  delete ptr;

  if(table->hasColumn(ENDVALDATE)){
    ptr = table->column(ENDVALDATE)->data();
    std::string s = getStringColumnRow(ptr, row);
    if(s[0] != ' '){
      _end_valdate = s;
      _has_endvaldate = true;
    }
    delete ptr;
  }
    

  ptr = table->column(SUBDATE)->data();
  _subdate = getStringColumnRow(ptr, row);
  delete ptr;
  
  ptr = table->column(DATE)->data();
  _date = getStringColumnRow(ptr, row);
  delete ptr;
  
  ptr = table->column(EXT_SEQUENCE)->data();
  _extSequence = getStringColumnRow(ptr, row);
  delete ptr;
  
  ptr = table->column(EXT_SEQUENCE_ID)->data();
  _extSequenceIdentifier = getStringColumnRow(ptr, row);
  delete ptr;
  
  ptr = table->column(NAME)->data();
  _name = getStringColumnRow(ptr, row);
  delete ptr;
  
  ptr = table->column(CREATOR)->data();
  _creator = getStringColumnRow(ptr, row);
  delete ptr;
  
  ptr = table->column(MD5_SIGNATURE)->data();
  _signature = getStringColumnRow(ptr, row);
  delete ptr;

  ENDPROC
}

off_t VirtualCcfConstituent::size() const { PROC RETURN _size; }
bool VirtualCcfConstituent::isDir() const { PROC RETURN false; }
void VirtualCcfConstituent::sign() { PROC ENDPROC }
string VirtualCcfConstituent::signature() const { PROC RETURN _signature; }
string VirtualCcfConstituent::name() const { PROC RETURN _name; }
string VirtualCcfConstituent::basename() const { PROC RETURN _name; }
string VirtualCcfConstituent::dirname() const { PROC RETURN ""; }
bool VirtualCcfConstituent::isSigned() const { PROC RETURN true; }

bool VirtualCcfConstituent::isValid() const { PROC RETURN true; }

string VirtualCcfConstituent::telescope() const { PROC RETURN _telescope; }
string VirtualCcfConstituent::type() const { PROC RETURN _type; }
string VirtualCcfConstituent::scope() const { PROC RETURN _scope; }
int VirtualCcfConstituent::issue() const { PROC RETURN _issue; }
string VirtualCcfConstituent::extSequence() const { PROC RETURN _extSequence; }
string VirtualCcfConstituent::extSequenceIdentifier() const { PROC RETURN _extSequenceIdentifier; }
STime VirtualCcfConstituent::valdate() const { PROC RETURN _valdate; }
STime VirtualCcfConstituent::date() const { PROC RETURN _date; }
STime VirtualCcfConstituent::endvaldate() const { PROC RETURN _end_valdate; }
STime VirtualCcfConstituent::subdate() const { PROC RETURN _subdate; }
string VirtualCcfConstituent::creator() const{ PROC RETURN _creator; }

bool VirtualCcfConstituent::hasEndvaldate() const { PROC RETURN _has_endvaldate; }

void VirtualCcfConstituent::init() { PROC ENDPROC }

string VirtualCcfConstituent::category() const {
  PROC
  RETURN _category;
}
