// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (European Space Agency) 
// August 02, 1999
//
// A CCF constituent wthout a matching disk representation.
//
#ifndef VirtualCcfConstituent_H
#define VirtualCcfConstituent_H

#include <Tracer.h>
#include <STime.h>
#include <Dal.h>

#include "CommonCcfConstituent.h"

class VirtualCcfConstituent : public CommonCcfConstituent
{

 public:
  
  VirtualCcfConstituent(const Table * table, const unsigned long row = 0);
  ~VirtualCcfConstituent() {}

  // redefined from DirEntry
  off_t size() const;
  bool isDir() const;
  void sign();
  string signature() const;
  string name() const;
  string basename() const;
  string dirname() const;
  bool isSigned() const;

  // redefined from CcfConstituent
  bool isValid() const;

  // redefined from CcfConstituent (?)
  string telescope() const;
  string type() const;
  string scope() const;
  int issue() const;
  string extSequence() const;
  string extSequenceIdentifier() const;
  STime valdate() const;
  STime endvaldate() const;
  bool hasEndvaldate() const;
  STime date() const;
  STime subdate() const;
  string creator() const;
  string category() const;

 private:

  void init();

  string _telescope, _scope, _type, _extSequence,
    _extSequenceIdentifier, _category, _creator;
  int _issue;
  STime _valdate, _end_valdate, _date, _subdate, _initdate;

  bool _has_endvaldate;

  off_t _size;
  string _signature, _name;
  

};


#endif
