// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (European Space Agency) 
// April 04, 2000
//
#include <string>
#include <Dal.h>
#include <cifbuild.h>
#include <param.h>
#include <metatask.h>
#include <CalIndexSet.h>
#include <CalIndex.h>
#include <cassert>
#include <errstr.h>

#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>

int main() {
  
  const string t1 = "1998-01-01T00:00:00";
  const string t2 = "1998-02-01T00:00:00";
  const string t3 = "1998-03-01T00:00:00";
  const string cif = "ccf.cif";
  const string dir = "mytestccf";

  openParameters("cifbuild");
  setParameter("ccfpath",dir.c_str());
  setParameter("withccfpath", true);
  setParameter("withobservationdate",true);
  setParameter("analysisdate",t1);
  setParameter("calindexset", cif);
  setParameter("observationdate",t1);
  setParameter("category","XMMCCF");
  task(cifbuild);

  CalIndex tcif = CalIndex("rmtest.cif");
  CalIndexSet cifset(cif);
  for(unsigned long i=0; i<cifset.size(); i++)
    tcif.addConstituent(cifset.getConstituent(i));
  cifset.close();
  unsigned i = tcif.size();
  assert(tcif.removeConstituent("ABSCOEFS", "XMM"));
  assert(tcif.size() == (i-1));

  tcif.addConstituentsFromSet(cif);
  assert(tcif.size() == i);

  tcif.save();
}
  
