// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (European Space Agency) 
// April 04, 2000
//
#include <string>
#include <Dal.h>
#include <cifbuild.h>
#include <cifinsert.h>
#include <cifremove.h>
#include <param.h>
#include <metatask.h>
#include <CalIndexSet.h>
#include <CalIndex.h>
#include <cassert>
#include <errstr.h>

#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>

int main() {
  
  const string t1 = "1998-01-01T00:00:00";
  const string t2 = "1998-02-01T00:00:00";
  const string t3 = "1998-03-01T00:00:00";
  const string cif = "ccf.cif";
  const string dir = "mytestccf";

  openParameters("cifbuild");
  setParameter("withccfpath", true);
  setParameter("ccfpath",dir.c_str());
  setParameter("analysisdate",t1);
  setParameter("calindexset", cif);
  setParameter("withobservationdate",true);
  setParameter("observationdate",t1);
  setParameter("category","XMMCCF");
  task(cifbuild);

  CalIndexSet c = CalIndexSet(cif);
  unsigned i = c.size();
  c.close();

  openParameters("cifremove");
  setParameter("calindexset", cif);
  vector<string> p(1);
  p[0] = "XMM";
  setParameter("scopes", p);
  p[0] = "BORESIGHT";
  setParameter("types", p);
  task(cifremove);
  c = CalIndexSet(cif);
  assert(c.size() == (i-1));
  c.close();

  vector<string> cc(1, "mytestccf/XMM_BORESIGHT_0001.CCF");

  // this inserts
  openParameters("cifinsert");
  setParameter("calindexset", cif);
  setParameter("sets", cc);
  task(cifinsert);

  c = CalIndexSet(cif);
  assert(c.size() == i);
  c.close();
  
  // this doesn't
  openParameters("cifinsert");
  setParameter("calindexset", cif);
  setParameter("sets", cc);
  task(cifinsert);

  c = CalIndexSet(cif);
  assert(c.size() == i);
  c.close();

}
  
