// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine science & computing) 
// February 2001
//

// Finds the most recent (ie, with the highest issue number) CCF
// CALINDEX file in all those found in the SAS_CCFPATH environment
// variable.

#include <Directory.h>
#include <string>
#include <vector>
#include <iostream>
#include <cstdlib>
#include <CcfConstituentFactory.h>
#include <stringutil.h>

int main() {

  if(std::getenv("SAS_CCFPATH")){
    std::string ccfpath(std::getenv("SAS_CCFPATH"));
    std::vector<string> ccf_directory_list = breakup(ccfpath, ":");
    list<CcfConstituent *> calindexes; 
    for(std::vector<std::string>::const_iterator i =
	  ccf_directory_list.begin();
	i != ccf_directory_list.end(); ++i) {
      const string &s = *i;
      Directory d(s);
      d.filter("XMM_CALINDEX_????.CCF");
      for(Directory::iterator j = d.begin(); j != d.end(); j++) {
	CcfConstituent * c = ccfConstituentFactory->ccfConstituent((*j)->name());
	calindexes.push_back(c);
      }	
    }
    calindexes.sort(CcfConstituent::compare);
 
    for(list<CcfConstituent *>::const_iterator i = calindexes.begin();
	i != calindexes.end(); i++)
      cout << (*i)->name() << endl;
  }
}

